#!/usr/bin/env python

#
# install this script in /usr/bin/fanservice
# and install the following unit file into /etc/systemd/system
#
# [Unit]
# Description=Fan service
# After=multi-user.target
# [Service]
# Type=simple
# Restart=always
# RemainAfterExit=true
# ExecStart=/usr/bin/fanservice
# [Install]
# WantedBy=multi-user.target

import Adafruit_GPIO.I2C as I2C

import time
import os
import smbus
bus = smbus.SMBus(1)

import Adafruit_SSD1306

from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont

import subprocess
import math

hat_addr = 0x0d
rgb_effect_reg = 0x04
rgb_off_reg = 0x07
fan_reg = 0x08
count = 0
fanspeed = 1

# Raspberry Pi pin configuration:
RST = None     # on the PiOLED this pin isnt used

# 128x32 display with hardware I2C:
disp = Adafruit_SSD1306.SSD1306_128_32(rst=RST)

# Initialize library.
disp.begin()

# Clear display.
disp.clear()
disp.display()

# Create blank image for drawing.
# Make sure to create image with mode '1' for 1-bit color.
width = disp.width
height = disp.height
image = Image.new('1', (width, height))

# Get drawing object to draw on image.
draw = ImageDraw.Draw(image)

# Draw a black filled box to clear the image.
draw.rectangle((0,0,width,height), outline=0, fill=0)

# Load default font.
#font = ImageFont.load_default()

fontfile = "/usr/share/fonts/truetype/dejavu/DejaVuSans.ttf"
tempfont = ImageFont.truetype(fontfile, 14)
ipfont = ImageFont.truetype(fontfile, 11)

def setFanSpeed(speed):
    global fanspeed
    if (fanspeed != speed):
        bus.write_byte_data(hat_addr, fan_reg, speed&0xff)
    fanspeed = speed

setFanSpeed(0x00)

# we don't need the RGB LED's to burn power
bus.write_byte_data(hat_addr, rgb_off_reg, 0)

while True:
    #cmd = os.popen('vcgencmd measure_temp').readline()
    #CPU_TEMP = math.ceil(float((cmd.replace("temp=","").replace("'C\n",""))))
    #CPU_TEMP = 101
    CPU_TEMP = open("/sys/class/thermal/thermal_zone0/temp", "r").readline();
    temp = math.ceil(int(CPU_TEMP) / 1000)

    # Draw a black filled box to clear the image.
    draw.rectangle((0,0,width,height), outline=0, fill=0)

    IP = os.popen('hostname -I').readline().split()
    IP0 = IP[0]
    IP1 = IP[1]
    #IP0 = IP1 = '255.255.255.255'
    draw.text((0, 8), str(temp), font=tempfont, fill=255)
    draw.text((30, 0), str(IP0),  font=ipfont, fill=255)
    draw.text((30, 16), str(IP1),  font=ipfont, fill=255)

    # Display image.
    disp.image(image)
    disp.display()

#
# fan speeds: 0: off, 1: full, 2: 20%, 3: 30%, ... 9: 90%
#

    if temp >= 60:
        setFanSpeed(0x1)
    elif temp >= 55:
        setFanSpeed(0x5)
    elif temp <= 50:
        setFanSpeed(0x00)
    
    time.sleep(5)
